# Hasherino
![PyPI - Downloads](https://img.shields.io/pypi/dm/hasherino)
<img alt="PyPI - Version" src="https://img.shields.io/pypi/v/hasherino">
<img alt="Python Version from PEP 621 TOML" src="https://img.shields.io/python/required-version-toml?tomlFilePath=https%3A%2F%2Fraw.githubusercontent.com%2FHashy-Software%2Fhasherino%2Fmain%2Fpyproject.toml">
<a href="https://github.com/psf/black"><img alt="Code style: black" src="https://img.shields.io/badge/code%20style-black-000000.svg"></a>

Hasherino is a (pre-alpha) twitch chat client with some extra features.

## Install
Check out [releases](https://github.com/Hashy-Software/hasherino/releases) for the latest Windows and Linux builds or install from [PyPI](https://pypi.org/project/hasherino/). 

## Features 

* [X] Auto color cycling

  <img src="https://github.com/Hashy-Software/hasherino/assets/38195951/90fa6cf8-44a3-43b5-97c3-ccfd0df098a0" width="400"/>

* [X] Dark and light modes

  <img src="https://github.com/Hashy-Software/hasherino/assets/38195951/fe714eda-f699-47a7-9636-7181d0767437" width="400"/>

* [X] Twitch Emote support
* [-] 7TV emote support(channel emotes are supported, not personal emotes).
* [X] Emote name completion(ctrl + e)
* [X] User name completion(ctrl + u)
* [ ] 7TV badges and paint
* [ ] Multiple tabs

## Bug reporting
Please create a [new issue](https://github.com/Hashy-Software/hasherino/issues/new) describing your bug. If necessary, attach your log file(path is on Settings > Debug) after reproducing the bug the last time you ran hasherino.
